Join chat by code
^^^^^^^^^^^^^^^^^

Join chat process contains of:

#. "invitation code" verifies
#. chat status was set as "ready"
#. "user token" was created
#. generate system message that chat is ready